@@ -40,12 +40,15 @@
 ;;;; END C binding
 
 ;; structure to store links
-(defstruct location host port type uri tls
+(defstruct location host port type uri tls text
            :predicate)
 
 ;;;; kiosk mode 
 (defparameter *kiosk-mode* nil)
 
+;;;; no split mode
+(defparameter *no-split* nil)
+
 (defmacro kiosk-mode(&body code)
   "prevent code if kiosk mode is enabled"
   `(progn
@@ -144,6 +147,7 @@
                    sock
                    :external-format '(:utf-8 :eol-style :lf)
                    :unwrap-stream-p t
+                   ;;:verify nil
                    :hostname host)))
                  ;; store in metadata that we are using TLS
              (setf (location-tls (car *history*)) t)
@@ -184,7 +188,7 @@
           (field      (split (subseq line 1) #\Tab)))
 
       ;; if split worked
-      (when (= (length field) 4)
+      (when (>= (length field) 4)
         (let ((line-number (+ 1 (hash-table-count *links*)))
               (text (car field))
               (uri  (cadr field))
@@ -203,13 +207,13 @@
                 ;; 0 text file
                 (check "0"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type ))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'file line-number))
 
                 ;; 1 directory
                 (check "1"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type ))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'folder line-number))
 
                 ;; 2 CSO phone-book
@@ -235,7 +239,7 @@
                 ;; 7 Index search server
                 (check "7"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type ))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'red line-number))
 
                 ;; 8 Telnet session
@@ -245,7 +249,7 @@
                 ;; 9 Binary
                 (check "9"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type ))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'red line-number))
 
                 ;; + redundant server
@@ -259,13 +263,13 @@
                 ;; g GIF file
                 (check "g"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'red line-number))
 
                 ;; I image
                 (check "I"
                        (setf (gethash line-number *links*)
-                             (make-location :host host :port port :uri uri :type line-type ))
+                             (make-location :host host :port port :uri uri :type line-type :text text))
                        (print-with-color text 'red line-number))
 
                 ;; h http link
@@ -434,9 +438,13 @@
          (c-kiosk-pledge)
          (setf *kiosk-mode* t))
 
+        ((string= "-t" url)
+         (setf *no-split* t))
+
         ((= 0 (or (search "file://" url) 1))
          (load-file-menu (subseq url 7))
          (make-location :host 'local-file
+                        :text url
                         :port nil
                         :type "1"
                         :uri url))
@@ -458,6 +466,8 @@
                                        (parse-integer (car host-port))
                                        70)
 
+                             :text url
+
                              ;; if type is empty we default to "1"
                              :type (let ((type (pop infos)))
                                      (if (< 0 (length type)) type "1"))
@@ -521,7 +531,17 @@
 
     ;; show history
     ((string= "h" input)
-     (format t "~{~a~%~}" *history*))
+      (setf *links* (make-hash-table))
+        (loop for element in *history*
+          do
+            (formatted-output
+              (format nil "~a~a	~a	~a	~a~%"
+                    (location-type element)
+                    (location-text element)
+                    (location-uri element)
+                    (location-host element)
+                    (location-port element)))))
+
 
     ;; follow a link
     (t
@@ -580,7 +600,9 @@
   ;; so if the user doesn't want to scroll
   ;; we break the loop and then execute the command
   (let ((input nil))
-    (let ((rows (- (c-termsize) 1))) ; -1 for command bar
+    (let ((rows (if *no-split*
+                    -1
+                    (* (- (c-termsize) 1))))) ; -1 for command bar
 
       (loop for line across *buffer*
          counting line into row
@@ -766,14 +788,14 @@
   ;; re-enable SIGINT (Ctrl+C) disabled for loading clic
   (ext:set-signal-handler ext:+sigint+ 'quit)
 
-  (ignore-errors ;; lisp is magic
+  (handler-case
     (let ((destination (car (last
                              (loop for element in (get-argv)
                                 collect (parse-url element))))))
 
       ;; if we didn't passed a url as parameter, use a default
       (if (not (location-p destination))
-          (setf destination (make-location :host "gopherproject.org" :port 70 :uri "/" :type "1")))
+          (setf destination (make-location :host "gopherproject.org" :port 70 :uri "/" :type "1" :text "gopherproject")))
 
       ;; is there an output redirection ?
       (if (ttyp)
@@ -789,7 +811,11 @@
                   ;; we continue to the shell if we are in a terminal
                   (shell)))
 	    (format t "~a kB in.~%" (floor (/ *total-bandwidth-in* 1024.0))))
-          (pipe-to-stdout destination)))))
+          (pipe-to-stdout destination)))
+    (t (error)
+	(progn
+	  (format t "Something went wrong~%")
+          (print error)))))
 
 ;; we allow ecl to use a new kind of argument
 ;; not sure how it works but that works
